/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryrenderer.sip"
#include <qgeometryrenderer.h>
#line 99 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 127 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 130 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 183 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 252 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 255 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameraselector.sip"
#include <qcameraselector.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclearbuffers.sip"
#include <qclearbuffers.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qclipplane.sip"
#include <qclipplane.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcomputecommand.sip"
#include <qcomputecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcolormask.sip"
#include <qcolormask.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcullface.sip"
#include <qcullface.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthrange.sip"
#include <qdepthrange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdepthtest.sip"
#include <qdepthtest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdirectionallight.sip"
#include <qdirectionallight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdispatchcompute.sip"
#include <qdispatchcompute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qdithering.sip"
#include <qdithering.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qeffect.sip"
#include <qeffect.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qenvironmentlight.sip"
#include <qenvironmentlight.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfilterkey.sip"
#include <qfilterkey.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qframegraphnode.sip"
#include <qframegraphnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrontface.sip"
#include <qfrontface.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qfrustumculling.sip"
#include <qfrustumculling.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometry.sip"
#include <qgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qgeometryfactory.sip"
#include <qgeometryfactory.h>
#line 326 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 349 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 352 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 355 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 384 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 387 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 390 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 393 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 396 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 431 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 436 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 439 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 442 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 445 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 448 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 451 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 454 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 457 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 460 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 463 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 466 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 469 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 472 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 475 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQGeometryRenderer.cpp"


class sipQt3DRender_QGeometryRenderer : public ::Qt3DRender::QGeometryRenderer
{
public:
    sipQt3DRender_QGeometryRenderer(::Qt3DCore::QNode*);
    virtual ~sipQt3DRender_QGeometryRenderer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QGeometryRenderer(const sipQt3DRender_QGeometryRenderer &);
    sipQt3DRender_QGeometryRenderer &operator = (const sipQt3DRender_QGeometryRenderer &);

    char sipPyMethods[8];
};

sipQt3DRender_QGeometryRenderer::sipQt3DRender_QGeometryRenderer(::Qt3DCore::QNode*a0): ::Qt3DRender::QGeometryRenderer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QGeometryRenderer::~sipQt3DRender_QGeometryRenderer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QGeometryRenderer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QGeometryRenderer);

    return ::Qt3DRender::QGeometryRenderer::metaObject();
}

int sipQt3DRender_QGeometryRenderer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QGeometryRenderer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QGeometryRenderer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QGeometryRenderer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QGeometryRenderer, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QGeometryRenderer::qt_metacast(_clname));
}

void sipQt3DRender_QGeometryRenderer::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QGeometryRenderer::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DRender_7(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QGeometryRenderer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QGeometryRenderer::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QGeometryRenderer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QGeometryRenderer::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DRender_QGeometryRenderer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QGeometryRenderer::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QGeometryRenderer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QGeometryRenderer::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QGeometryRenderer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QGeometryRenderer::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QGeometryRenderer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QGeometryRenderer::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QGeometryRenderer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QGeometryRenderer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_instanceCount, "instanceCount(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_instanceCount(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_instanceCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->instanceCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_instanceCount, doc_Qt3DRender_QGeometryRenderer_instanceCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_vertexCount, "vertexCount(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_vertexCount(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_vertexCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->vertexCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_vertexCount, doc_Qt3DRender_QGeometryRenderer_vertexCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_indexOffset, "indexOffset(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_indexOffset(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_indexOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->indexOffset();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_indexOffset, doc_Qt3DRender_QGeometryRenderer_indexOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_firstInstance, "firstInstance(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_firstInstance(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_firstInstance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->firstInstance();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_firstInstance, doc_Qt3DRender_QGeometryRenderer_firstInstance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_firstVertex, "firstVertex(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_firstVertex(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_firstVertex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->firstVertex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_firstVertex, doc_Qt3DRender_QGeometryRenderer_firstVertex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_restartIndexValue, "restartIndexValue(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_restartIndexValue(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_restartIndexValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->restartIndexValue();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_restartIndexValue, doc_Qt3DRender_QGeometryRenderer_restartIndexValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_verticesPerPatch, "verticesPerPatch(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_verticesPerPatch(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_verticesPerPatch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->verticesPerPatch();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_verticesPerPatch, doc_Qt3DRender_QGeometryRenderer_verticesPerPatch);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_primitiveRestartEnabled, "primitiveRestartEnabled(self) -> bool");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_primitiveRestartEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_primitiveRestartEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->primitiveRestartEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_primitiveRestartEnabled, doc_Qt3DRender_QGeometryRenderer_primitiveRestartEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_geometry, "geometry(self) -> QGeometry|None");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_geometry(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_geometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            ::Qt3DRender::QGeometry*sipRes;

            sipRes = sipCpp->geometry();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QGeometry, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_geometry, doc_Qt3DRender_QGeometryRenderer_geometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_primitiveType, "primitiveType(self) -> QGeometryRenderer.PrimitiveType");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_primitiveType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_primitiveType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            ::Qt3DRender::QGeometryRenderer::PrimitiveType sipRes;

            sipRes = sipCpp->primitiveType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QGeometryRenderer_PrimitiveType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_primitiveType, doc_Qt3DRender_QGeometryRenderer_primitiveType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_geometryFactory, "geometryFactory(self) -> QGeometryFactory");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_geometryFactory(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_geometryFactory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            ::Qt3DRender::QGeometryFactoryPtr*sipRes;

            sipRes = new ::Qt3DRender::QGeometryFactoryPtr(sipCpp->geometryFactory());

            return sipConvertFromNewType(sipRes, sipType_QSharedPointer_0100Qt3DRender_QGeometryFactory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_geometryFactory, doc_Qt3DRender_QGeometryRenderer_geometryFactory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setGeometryFactory, "setGeometryFactory(self, factory: QGeometryFactory)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setGeometryFactory(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setGeometryFactory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryFactoryPtr* a0;
        int a0State = 0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, sipType_QSharedPointer_0100Qt3DRender_QGeometryFactory, &a0, &a0State))
        {
            sipCpp->setGeometryFactory(*a0);
            sipReleaseType(const_cast< ::Qt3DRender::QGeometryFactoryPtr *>(a0), sipType_QSharedPointer_0100Qt3DRender_QGeometryFactory, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setGeometryFactory, doc_Qt3DRender_QGeometryRenderer_setGeometryFactory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setInstanceCount, "setInstanceCount(self, instanceCount: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setInstanceCount(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setInstanceCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setInstanceCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setInstanceCount, doc_Qt3DRender_QGeometryRenderer_setInstanceCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setVertexCount, "setVertexCount(self, vertexCount: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setVertexCount(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setVertexCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setVertexCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setVertexCount, doc_Qt3DRender_QGeometryRenderer_setVertexCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setIndexOffset, "setIndexOffset(self, indexOffset: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setIndexOffset(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setIndexOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setIndexOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setIndexOffset, doc_Qt3DRender_QGeometryRenderer_setIndexOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setFirstInstance, "setFirstInstance(self, firstInstance: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setFirstInstance(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setFirstInstance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setFirstInstance(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setFirstInstance, doc_Qt3DRender_QGeometryRenderer_setFirstInstance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setFirstVertex, "setFirstVertex(self, firstVertex: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setFirstVertex(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setFirstVertex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setFirstVertex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setFirstVertex, doc_Qt3DRender_QGeometryRenderer_setFirstVertex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setRestartIndexValue, "setRestartIndexValue(self, index: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setRestartIndexValue(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setRestartIndexValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setRestartIndexValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setRestartIndexValue, doc_Qt3DRender_QGeometryRenderer_setRestartIndexValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setVerticesPerPatch, "setVerticesPerPatch(self, verticesPerPatch: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setVerticesPerPatch(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setVerticesPerPatch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setVerticesPerPatch(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setVerticesPerPatch, doc_Qt3DRender_QGeometryRenderer_setVerticesPerPatch);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setPrimitiveRestartEnabled, "setPrimitiveRestartEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setPrimitiveRestartEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setPrimitiveRestartEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setPrimitiveRestartEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setPrimitiveRestartEnabled, doc_Qt3DRender_QGeometryRenderer_setPrimitiveRestartEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setGeometry, "setGeometry(self, geometry: QGeometry|None)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setGeometry(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QGeometry* a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, sipType_Qt3DRender_QGeometry, &a0))
        {
            sipCpp->setGeometry(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setGeometry, doc_Qt3DRender_QGeometryRenderer_setGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setPrimitiveType, "setPrimitiveType(self, primitiveType: QGeometryRenderer.PrimitiveType)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setPrimitiveType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setPrimitiveType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QGeometryRenderer::PrimitiveType a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, sipType_Qt3DRender_QGeometryRenderer_PrimitiveType, &a0))
        {
            sipCpp->setPrimitiveType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setPrimitiveType, doc_Qt3DRender_QGeometryRenderer_setPrimitiveType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_indexBufferByteOffset, "indexBufferByteOffset(self) -> int");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_indexBufferByteOffset(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_indexBufferByteOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->indexBufferByteOffset();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_indexBufferByteOffset, doc_Qt3DRender_QGeometryRenderer_indexBufferByteOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_setIndexBufferByteOffset, "setIndexBufferByteOffset(self, offset: int)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_setIndexBufferByteOffset(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_setIndexBufferByteOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, &a0))
        {
            sipCpp->setIndexBufferByteOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_setIndexBufferByteOffset, doc_Qt3DRender_QGeometryRenderer_setIndexBufferByteOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer_sceneChangeEvent, "sceneChangeEvent(self, change: QSceneChange)");

extern "C" {static PyObject *meth_Qt3DRender_QGeometryRenderer_sceneChangeEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QGeometryRenderer_sceneChangeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::Qt3DCore::QSceneChangePtr* a0;
        int a0State = 0;
        ::Qt3DRender::QGeometryRenderer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DRender_QGeometryRenderer, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QSceneChange, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::Qt3DRender::QGeometryRenderer::sceneChangeEvent(*a0) : sipCpp->sceneChangeEvent(*a0));
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChangePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeometryRenderer, sipName_sceneChangeEvent, doc_Qt3DRender_QGeometryRenderer_sceneChangeEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QGeometryRenderer(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QGeometryRenderer(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QGeometryRenderer *sipCpp = reinterpret_cast< ::Qt3DRender::QGeometryRenderer *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QGeometryRenderer)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QComponent)->ctd_cast(static_cast< ::Qt3DCore::QComponent *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QGeometryRenderer(void *, int);}
static void release_Qt3DRender_QGeometryRenderer(void *sipCppV, int)
{
    ::Qt3DRender::QGeometryRenderer *sipCpp = reinterpret_cast< ::Qt3DRender::QGeometryRenderer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QGeometryRenderer(Py_ssize_t);}
static void *array_Qt3DRender_QGeometryRenderer(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QGeometryRenderer[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QGeometryRenderer(void *);}
static void array_delete_Qt3DRender_QGeometryRenderer(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QGeometryRenderer *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QGeometryRenderer(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QGeometryRenderer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QGeometryRenderer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QGeometryRenderer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QGeometryRenderer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QGeometryRenderer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QGeometryRenderer *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QGeometryRenderer(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QGeometryRenderer[] = {{2, 2, 1}};


static PyMethodDef methods_Qt3DRender_QGeometryRenderer[] = {
    {sipName_firstInstance, meth_Qt3DRender_QGeometryRenderer_firstInstance, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_firstInstance},
    {sipName_firstVertex, meth_Qt3DRender_QGeometryRenderer_firstVertex, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_firstVertex},
    {sipName_geometry, meth_Qt3DRender_QGeometryRenderer_geometry, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_geometry},
    {sipName_geometryFactory, meth_Qt3DRender_QGeometryRenderer_geometryFactory, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_geometryFactory},
    {sipName_indexBufferByteOffset, meth_Qt3DRender_QGeometryRenderer_indexBufferByteOffset, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_indexBufferByteOffset},
    {sipName_indexOffset, meth_Qt3DRender_QGeometryRenderer_indexOffset, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_indexOffset},
    {sipName_instanceCount, meth_Qt3DRender_QGeometryRenderer_instanceCount, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_instanceCount},
    {sipName_primitiveRestartEnabled, meth_Qt3DRender_QGeometryRenderer_primitiveRestartEnabled, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_primitiveRestartEnabled},
    {sipName_primitiveType, meth_Qt3DRender_QGeometryRenderer_primitiveType, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_primitiveType},
    {sipName_restartIndexValue, meth_Qt3DRender_QGeometryRenderer_restartIndexValue, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_restartIndexValue},
    {sipName_sceneChangeEvent, meth_Qt3DRender_QGeometryRenderer_sceneChangeEvent, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_sceneChangeEvent},
    {sipName_setFirstInstance, meth_Qt3DRender_QGeometryRenderer_setFirstInstance, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setFirstInstance},
    {sipName_setFirstVertex, meth_Qt3DRender_QGeometryRenderer_setFirstVertex, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setFirstVertex},
    {sipName_setGeometry, meth_Qt3DRender_QGeometryRenderer_setGeometry, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setGeometry},
    {sipName_setGeometryFactory, meth_Qt3DRender_QGeometryRenderer_setGeometryFactory, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setGeometryFactory},
    {sipName_setIndexBufferByteOffset, meth_Qt3DRender_QGeometryRenderer_setIndexBufferByteOffset, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setIndexBufferByteOffset},
    {sipName_setIndexOffset, meth_Qt3DRender_QGeometryRenderer_setIndexOffset, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setIndexOffset},
    {sipName_setInstanceCount, meth_Qt3DRender_QGeometryRenderer_setInstanceCount, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setInstanceCount},
    {sipName_setPrimitiveRestartEnabled, meth_Qt3DRender_QGeometryRenderer_setPrimitiveRestartEnabled, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setPrimitiveRestartEnabled},
    {sipName_setPrimitiveType, meth_Qt3DRender_QGeometryRenderer_setPrimitiveType, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setPrimitiveType},
    {sipName_setRestartIndexValue, meth_Qt3DRender_QGeometryRenderer_setRestartIndexValue, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setRestartIndexValue},
    {sipName_setVertexCount, meth_Qt3DRender_QGeometryRenderer_setVertexCount, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setVertexCount},
    {sipName_setVerticesPerPatch, meth_Qt3DRender_QGeometryRenderer_setVerticesPerPatch, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_setVerticesPerPatch},
    {sipName_vertexCount, meth_Qt3DRender_QGeometryRenderer_vertexCount, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_vertexCount},
    {sipName_verticesPerPatch, meth_Qt3DRender_QGeometryRenderer_verticesPerPatch, METH_VARARGS, doc_Qt3DRender_QGeometryRenderer_verticesPerPatch}
};

static sipEnumMemberDef enummembers_Qt3DRender_QGeometryRenderer[] = {
    {sipName_LineLoop, static_cast<int>(::Qt3DRender::QGeometryRenderer::LineLoop), 84},
    {sipName_LineStrip, static_cast<int>(::Qt3DRender::QGeometryRenderer::LineStrip), 84},
    {sipName_LineStripAdjacency, static_cast<int>(::Qt3DRender::QGeometryRenderer::LineStripAdjacency), 84},
    {sipName_Lines, static_cast<int>(::Qt3DRender::QGeometryRenderer::Lines), 84},
    {sipName_LinesAdjacency, static_cast<int>(::Qt3DRender::QGeometryRenderer::LinesAdjacency), 84},
    {sipName_Patches, static_cast<int>(::Qt3DRender::QGeometryRenderer::Patches), 84},
    {sipName_Points, static_cast<int>(::Qt3DRender::QGeometryRenderer::Points), 84},
    {sipName_TriangleFan, static_cast<int>(::Qt3DRender::QGeometryRenderer::TriangleFan), 84},
    {sipName_TriangleStrip, static_cast<int>(::Qt3DRender::QGeometryRenderer::TriangleStrip), 84},
    {sipName_TriangleStripAdjacency, static_cast<int>(::Qt3DRender::QGeometryRenderer::TriangleStripAdjacency), 84},
    {sipName_Triangles, static_cast<int>(::Qt3DRender::QGeometryRenderer::Triangles), 84},
    {sipName_TrianglesAdjacency, static_cast<int>(::Qt3DRender::QGeometryRenderer::TrianglesAdjacency), 84},
};

PyDoc_STRVAR(doc_Qt3DRender_QGeometryRenderer, "\1QGeometryRenderer(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QGeometryRenderer[] = {
    {"indexBufferByteOffsetChanged(int)", "\1indexBufferByteOffsetChanged(self, offset: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"primitiveTypeChanged(PrimitiveType)|(Qt3DRender::QGeometryRenderer::PrimitiveType)", "\1primitiveTypeChanged(self, primitiveType: QGeometryRenderer.PrimitiveType)", SIP_NULLPTR, SIP_NULLPTR},
    {"geometryChanged(QGeometry*)|(Qt3DRender::QGeometry*)", "\1geometryChanged(self, geometry: QGeometry|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"primitiveRestartEnabledChanged(bool)", "\1primitiveRestartEnabledChanged(self, primitiveRestartEnabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"verticesPerPatchChanged(int)", "\1verticesPerPatchChanged(self, verticesPerPatch: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"restartIndexValueChanged(int)", "\1restartIndexValueChanged(self, restartIndexValue: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"firstVertexChanged(int)", "\1firstVertexChanged(self, firstVertex: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"firstInstanceChanged(int)", "\1firstInstanceChanged(self, firstInstance: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"indexOffsetChanged(int)", "\1indexOffsetChanged(self, indexOffset: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"vertexCountChanged(int)", "\1vertexCountChanged(self, vertexCount: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"instanceCountChanged(int)", "\1instanceCountChanged(self, instanceCount: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QGeometryRenderer = {
    &::Qt3DRender::QGeometryRenderer::staticMetaObject,
    0,
    signals_Qt3DRender_QGeometryRenderer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QGeometryRenderer = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QGeometryRenderer,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QGeometryRenderer,
    },
    {
        sipNameNr_QGeometryRenderer,
        {0, 0, 1},
        25, methods_Qt3DRender_QGeometryRenderer,
        12, enummembers_Qt3DRender_QGeometryRenderer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QGeometryRenderer,
    -1,
    -1,
    supers_Qt3DRender_QGeometryRenderer,
    SIP_NULLPTR,
    init_type_Qt3DRender_QGeometryRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QGeometryRenderer,
    SIP_NULLPTR,
    array_Qt3DRender_QGeometryRenderer,
    SIP_NULLPTR,
    release_Qt3DRender_QGeometryRenderer,
    cast_Qt3DRender_QGeometryRenderer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QGeometryRenderer,
    sizeof (::Qt3DRender::QGeometryRenderer),
};
